@@ -109,7 +109,6 @@ from vdsm.virt import vmxml
 from . import core
 from . import hwclass
 
-import re
 
 log = logging.getLogger("virt.lease")
 
@@ -149,16 +148,7 @@ class Device(core.Base):
 
     @classmethod
     def from_xml_tree(cls, log, dev, meta):
-        params = {
-            'type': dev.tag,
-            'device': core.find_device_type(dev),
-            'lease_id': vmxml.text(vmxml.find_first(dev, 'key')),
-            'sd_id': vmxml.text(vmxml.find_first(dev, 'lockspace')),
-            'path': vmxml.find_attr(dev, 'target', 'path'),
-            'offset': vmxml.find_attr(dev, 'target', 'offset'),
-        }
-        core.update_device_params(params, dev)
-        core.update_device_params_from_meta(params, meta)
+        params = parse_xml(dev, meta)
         return cls(log, **params)
 
     @classmethod
@@ -221,6 +211,20 @@ class Device(core.Base):
                 "at {addr:#x}>").format(self=self, addr=id(self))
 
 
+def parse_xml(dev, meta):
+    params = {
+        'type': dev.tag,
+        'device': core.find_device_type(dev),
+        'lease_id': vmxml.text(vmxml.find_first(dev, 'key')),
+        'sd_id': vmxml.text(vmxml.find_first(dev, 'lockspace')),
+        'path': vmxml.find_attr(dev, 'target', 'path'),
+        'offset': vmxml.find_attr(dev, 'target', 'offset'),
+    }
+    core.update_device_params(params, dev)
+    core.update_device_params_from_meta(params, meta)
+    return params
+
+
 def find_device(vm_devices, query):
     """
     Find lease device in vm devices.
@@ -296,26 +300,23 @@ def _is_prepared(device):
     return "path" in device and "offset" in device
 
 
-def fixLeases(storage, xml_str, drive_objs):
-    leases = set(re.findall('(?<=LEASE-PATH:)[\w:-]+', xml_str))
-    for lease in leases:
-        lease_id, lease_sd_id = lease.split(':')
-
-        lease_info = _find_drive_lease_info(lease_sd_id, lease_id, drive_objs)
-        if lease_info is None:
-            # not a drive lease, must be a vm lease
-            res = storage.lease_info(
-                dict(sd_id=lease_sd_id, lease_id=lease_id))
-            lease_info = res["result"]
-
-        xml_str = xml_str.replace('LEASE-PATH:' + lease,
-                                  lease_info["path"])
-        xml_str = xml_str.replace('LEASE-OFFSET:' + lease,
-                                  str(lease_info["offset"]))
-    return xml_str
+def update_lease_element_from_info(lease_element, info, params, log):
+    target = vmxml.find_first(lease_element, 'target')
+    for (key, placeholder) in (
+            ('path', 'LEASE-PATH'),
+            ('offset', 'LEASE-OFFSET')):
+        value = target.attrib.get(key, None)
+        if value is None or value.startswith(placeholder):
+            old_value = target.attrib[key]
+            target.attrib[key] = str(info[key])
+            if old_value != info[key]:
+                log.info(
+                    'lease %s:%s %s: %r -> %r',
+                    params['sd_id'], params['lease_id'],
+                    key, old_value, info[key])
 
 
-def _find_drive_lease_info(sd_id, lease_id, drive_objs):
+def find_drive_lease_info(sd_id, lease_id, drive_objs):
     for drive_obj in drive_objs:
         volume_chain = getattr(drive_obj, "volumeChain", [])
         for vol_info in volume_chain[-1:]:
